@@ -1,5 +1,6 @@
 import torch
 import numpy as np
+import os
 
 def to_float_tensor(item): return item.float().div_(255.)
 def add_colour_dimension(item):
@@ -24,6 +25,18 @@ def recursive_np_and(boolean_arrays):
     if len(boolean_arrays) == 1: return boolean_arrays[0]
     return np.logical_and(boolean_arrays[0],recursive_np_and(boolean_arrays[1:]))
 
+def np_load_all(dir_name,comb_method='stack',restrict=-1):
+    all_fnames = os.listdir(dir_name)
+    if restrict == -1:
+        restrict = len(all_fnames)
+    all_arrs = [np.load(os.path.join(dir_name,fn)) for fn in all_fnames[:restrict]]
+    if comb_method=='none':
+        return all_arrs
+    elif comb_method=='cat':
+        return np.concatenate(all_arrs)
+    elif comb_method=='stack':
+        return np.stack(all_arrs)
+
 def noiseify(pytensor,constant):
     noise = torch.randn_like(pytensor)
     noise /= noise.max()
